#

##

    	fernet_1_tar

    	utility

    		nocturnal_1 fernet_1_tar produce_key
    		nocturnal_1 fernet_1_tar encrypt --dir ""
    		nocturnal_1 fernet_1_tar decrypt --file ""

    	quests

    		directory to fernet_tar:

    			original:
    				directory_1

    			build:
    				directory_1.tar
    				directory_1.tar.reversed

    				directory_1.tar.fernet
    				directory_1.tar.fernet.reversed

    			unbuild:
    				directory_1

    		fernet_tar to directory: